aboutsummaryrefslogtreecommitdiff
path: root/bpkg/pkg-unpack.cxx
diff options
context:
space:
mode:
authorKaren Arutyunov <karen@codesynthesis.com>2018-04-27 15:53:00 +0300
committerKaren Arutyunov <karen@codesynthesis.com>2018-04-27 15:55:18 +0300
commita2b084651909929d58f6b4bc0f3c742d87ee31f6 (patch)
tree63ef970e6edc44473ca9450dce93cbd130127d57 /bpkg/pkg-unpack.cxx
parentf86216071cd4d8d120a8afb83f4b452ef7892ea1 (diff)
Add support for repository fragments
Diffstat (limited to 'bpkg/pkg-unpack.cxx')
-rw-r--r--bpkg/pkg-unpack.cxx16
1 files changed, 8 insertions, 8 deletions
diff --git a/bpkg/pkg-unpack.cxx b/bpkg/pkg-unpack.cxx
index ace8d53..984a41e 100644
--- a/bpkg/pkg-unpack.cxx
+++ b/bpkg/pkg-unpack.cxx
@@ -106,7 +106,7 @@ namespace bpkg
p->version = move (v);
p->state = package_state::unpacked;
- p->repository = move (rl);
+ p->repository_fragment = move (rl);
p->src_root = move (d);
p->purge_src = purge;
p->manifest_checksum = move (mc);
@@ -172,8 +172,8 @@ namespace bpkg
o, c, t, d, m.name, m.version, true /* check_external */))
m.version = move (*v);
// Use the special root repository as the repository of this
// package.
//
return pkg_unpack (o,
c,
@@ -215,14 +215,14 @@ namespace bpkg
if (ap == nullptr)
fail << "package " << n << " " << v << " is not available";
// Pick a directory-based repository. They are always local, so we pick
// the first one.
//
const package_location* pl (nullptr);
for (const package_location& l: ap->locations)
{
- if (l.repository.load ()->location.directory_based ())
+ if (l.repository_fragment.load ()->location.directory_based ())
{
pl = &l;
break;
@@ -235,9 +235,9 @@ namespace bpkg
if (verb > 1)
text << "unpacking " << pl->location.leaf () << " "
- << "from " << pl->repository->name;
+ << "from " << pl->repository_fragment->name;
- const repository_location& rl (pl->repository->location);
+ const repository_location& rl (pl->repository_fragment->location);
return pkg_unpack (o,
c,
@@ -172,8 +172,8 @@ namespace bpkg
o, c, t, d, m.name, m.version, true /* check_external */))
m.version = move (*v);
- // Use the special root repository as the repository of this
- // package.
+ // Use the special root repository fragment as the repository fragment of
+ // this package.
//
return pkg_unpack (o,
@@ -215,14 +215,14 @@ namespace bpkg
if (ap == nullptr)
fail << "package " << n << " " << v << " is not available";
- // Pick a directory-based repository. They are always local, so we pick
- // the first one.
+ // Pick a directory-based repository fragment. They are always local, so we
+ // pick the first one.
//
const package_location* pl (nullptr);